hal: configure slimbus Rx channel for APTX AD at 96KHz
Configure slimbus Rx for aptX Adaptive at 96KHz to reduce
the time to transfer the packets across the slimbus.
Change-Id: Iea3beafb5d063ac0bcbb0c76727df2eaed2606a0
diff --git a/hal/audio_extn/a2dp.c b/hal/audio_extn/a2dp.c
index 19c839c..34d6334 100644
--- a/hal/audio_extn/a2dp.c
+++ b/hal/audio_extn/a2dp.c
@@ -1128,11 +1128,15 @@
} else {
sampling_rate = a2dp.enc_sampling_rate;
}
//For LDAC encoder and AAC decoder open slimbus port at
//96Khz for 48Khz input and 88.2Khz for 44.1Khz input.
if (((a2dp.bt_encoder_format == CODEC_TYPE_LDAC) ||
(a2dp.bt_decoder_format == CODEC_TYPE_SBC) ||
- (a2dp.bt_decoder_format == AUDIO_FORMAT_AAC)) &&
+ (a2dp.bt_decoder_format == AUDIO_FORMAT_AAC) ||
+ (a2dp.bt_encoder_format == CODEC_TYPE_APTX_AD)) &&
(sampling_rate == 48000 || sampling_rate == 44100 )) {
sampling_rate = sampling_rate *2;
}
@@ -1128,11 +1128,15 @@
sampling_rate = a2dp.enc_sampling_rate;
}
- //For LDAC encoder and AAC decoder open slimbus port at
- //96Khz for 48Khz input and 88.2Khz for 44.1Khz input.
+ /*
+ * For LDAC encoder and AAC decoder open slimbus port at
+ * 96Khz for 48Khz input and 88.2Khz for 44.1Khz input.
+ * For APTX AD encoder, open slimbus port at 96Khz for 48Khz input.
+ */
if (((a2dp.bt_encoder_format == CODEC_TYPE_LDAC) ||
(a2dp.bt_decoder_format == CODEC_TYPE_SBC) ||